.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`core.formatters`
==============================
.. automodule:: IPython.core.formatters

.. currentmodule:: IPython.core.formatters

16 Classes
----------

.. autoclass:: DisplayFormatter
  :members:
  :show-inheritance:

.. autoclass:: FormatterWarning
  :members:
  :show-inheritance:

.. autoclass:: FormatterABC
  :members:
  :show-inheritance:

.. autoclass:: BaseFormatter
  :members:
  :show-inheritance:

.. autoclass:: PlainTextFormatter
  :members:
  :show-inheritance:

.. autoclass:: HTMLFormatter
  :members:
  :show-inheritance:

.. autoclass:: MarkdownFormatter
  :members:
  :show-inheritance:

.. autoclass:: SVGFormatter
  :members:
  :show-inheritance:

.. autoclass:: PNGFormatter
  :members:
  :show-inheritance:

.. autoclass:: JPEGFormatter
  :members:
  :show-inheritance:

.. autoclass:: LatexFormatter
  :members:
  :show-inheritance:

.. autoclass:: JSONFormatter
  :members:
  :show-inheritance:

.. autoclass:: JavascriptFormatter
  :members:
  :show-inheritance:

.. autoclass:: PDFFormatter
  :members:
  :show-inheritance:

.. autoclass:: IPythonDisplayFormatter
  :members:
  :show-inheritance:

.. autoclass:: MimeBundleFormatter
  :members:
  :show-inheritance:

2 Functions
-----------

.. autofunction:: IPython.core.formatters.catch_format_error


.. autofunction:: IPython.core.formatters.format_display_data

